@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- $Id: properties.c 10756 2008-03-15 22:45:30Z callum $
+ $Id: properties.c 11187 2009-01-14 07:55:26Z diegoe $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -44,10 +44,6 @@
 
 #include <gconf/gconf-client.h>
 
-#include <libgnome/libgnome.h>
-
-#include <libgnomeui/libgnomeui.h>
-
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
 
